@@ -117,6 +117,11 @@ h5createGroup <- function(file, group) {
                       H5Tset_cset(tid, encoding)
                       tid
                     },
+                    complex = {
+                      ## We will store two numerics in the compound datatype
+                      tid <- .Call("_h5createComplexDataType", PACKAGE = 'rhdf5')
+                      tid
+                    },
                     { stop("datatype ",storage.mode, " not yet implemented.\n", 
                            "Try 'logical', 'double', 'integer', 'integer64' or 'character'.") } )
     } else {
@@ -527,8 +532,8 @@ h5createAttribute <- function(obj, attr, dims, maxdims = dims, file,
     } else {
       stop("Can not create attribute. 'dims' and 'maxdims' have to be numeric.")
     }
-
     on.exit(H5Sclose(sid), add = TRUE)
+    
     if (is.null(H5type)) {
         if (is.character(storage.mode)) {
             tid <- switch(storage.mode[1],
@@ -544,13 +549,22 @@ h5createAttribute <- function(obj, attr, dims, maxdims = dims, file,
                               H5Tset_size(tid, size) # NULL = variable.
                               tid
                           },
+                          logical = {
+                              tid <- H5Tenum_create(dtype_id = "H5T_NATIVE_UCHAR")
+                              H5Tenum_insert(tid, name = "TRUE", value = 1L)
+                              H5Tenum_insert(tid, name = "FALSE", value = 0L)
+                              H5Tenum_insert(tid, name = "NA", value = 255L)
+                              tid
+                          },
                           H5IdComponent=h5constants$H5T["H5T_STD_REF_OBJ"],
                           { stop("datatype ",storage.mode," not yet implemented. Try 'double', 'integer', or 'character'.") } )
         } else {
             stop("Can not create dataset. 'storage.mode' has to be a character.")
         }
     } else {
-        tid <- h5checkConstants("H5T", H5type)
+        if(grepl(pattern = "^[[:digit:]]+$", H5type)) {
+          tid <- H5type
+        }
     }
     if(!grepl(pattern = "^[[:digit:]]+$", tid)) {
         message("Can not create attribute. H5type unknown. Check h5const('H5T') for valid types.")
