@@ -2,4 +2,4 @@
 #include "myhdf5.h"
 #include <H5private.h>
 
-SEXP _h5fileLock();
+SEXP _h5fileLock(SEXP _file_name);
