@@ -16,6 +16,7 @@
 #include "H5S.h"
 #include "H5T.h"
 #include "H5P.h"
+#include "H5PL.h"
 #include "H5Z.h"
 #include "h5ls.h"
 #include "HandleList.h"
@@ -118,6 +119,7 @@ static R_CallMethodDef libraryRCalls[] = {
   {"_H5Scombine_select", (DL_FUNC) &_H5Scombine_select, 3},
   {"_H5Sselect_index", (DL_FUNC) &_H5Sselect_index, 3},
   {"_H5Tget_class", (DL_FUNC) &_H5Tget_class, 1},
+  {"_H5Tcreate", (DL_FUNC) &_H5Tcreate, 2},
   {"_H5Tcopy", (DL_FUNC) &_H5Tcopy, 1},
   {"_H5Tset_size", (DL_FUNC) &_H5Tset_size, 2},
   {"_H5Tget_size", (DL_FUNC) &_H5Tget_size, 1},
@@ -132,6 +134,8 @@ static R_CallMethodDef libraryRCalls[] = {
   {"_H5Tget_offset", (DL_FUNC) &_H5Tget_offset, 1},
   {"_H5Tenum_create", (DL_FUNC) &_H5Tenum_create, 1},
   {"_H5Tenum_insert", (DL_FUNC) &_H5Tenum_insert, 3},
+  {"_H5Tget_nmembers", (DL_FUNC) &_H5Tget_nmembers, 1},
+  {"_h5createComplexDataType", (DL_FUNC) &_h5createComplexDataType, 0},
   {"_H5Pcreate", (DL_FUNC) &_H5Pcreate, 1},
   {"_H5Pget_class", (DL_FUNC) &_H5Pget_class, 1},
   {"_H5Pcopy", (DL_FUNC) &_H5Pcopy, 1},
@@ -332,6 +336,9 @@ static R_CallMethodDef libraryRCalls[] = {
   {"_h5listOpenObjects", (DL_FUNC) &_h5listOpenObjects, 1},
   {"_h5getEnumNames", (DL_FUNC) &_h5getEnumNames, 1},
   {"_h5getEnumValues", (DL_FUNC) &_h5getEnumValues, 1},
+  {"_H5PLprepend", (DL_FUNC) &_H5PLprepend, 1},
+  {"_H5PLsize", (DL_FUNC) &_H5PLsize, 0},
+  {"_H5PLget", (DL_FUNC) &_H5PLget, 1},
 #ifdef _H5P_filters
   {"_H5Pset_lzf", (DL_FUNC) &_H5Pset_lzf, 2},
   {"_H5Pset_bzip2", (DL_FUNC) &_H5Pset_bzip2, 2},
