@@ -158,12 +158,12 @@ test_that("fixed length string attributes are correct", {
 
   H5Awrite(aid, attr_value) # string of length 7
   
-  H5Aclose(aid)
-  H5Sclose(sid)
-  H5Fclose(fid)
+  h5closeAll(aid, sid, fid)
   
   attr <- h5readAttributes(h5File, "/")
   expect_is(attr, class = "list")
   expect_equal(names(attr), attr_name)
   expect_equal(attr$name, attr_value)
 })
+
+expect_length(h5validObjects(), 0)
