@@ -3,6 +3,8 @@
 ## Current caveat is that we typically return an array even when there is only
 ## one dimension.
 
+library(rhdf5)
+
 h5file <- tempfile(pattern = "h5_roundtrip_", fileext = ".h5")
 
 test_that("data.frame columns survive a round trip", {
@@ -20,17 +22,18 @@ test_that("data.frame columns survive a round trip", {
             character(1) ),
         stringsAsFactors = FALSE
     )
+    test_frame_single <- test_frame['integer']
     
     
     expect_silent(h5write(obj = test_frame, file = h5file, name = 'data_frame'))
+    expect_silent(h5write(obj = test_frame_single, file = h5file, name = 'data_frame2'))
     
     expect_silent(back_frame <- h5read(file = h5file, name = "data_frame") )
+    expect_silent(back_frame2 <- h5read(file = h5file, name = "data_frame2") )
     expect_equivalent(back_frame$integer, test_frame$integer)
     expect_equivalent(back_frame$words, test_frame$words)
-    
 })
 
-
 test_that("character vectors survive a round trip", {
     
     words <- vapply(1:10, FUN = function(x) { 
@@ -55,3 +58,17 @@ test_that("UTF-8 strings are preserved", {
   expect_equivalent(input, output)
   expect_equal(Encoding(output), "UTF-8")
 })
+
+test_that("Complex numbers are writen to a compound datatype", {
+  
+  h5file <- tempfile(pattern = "h5_roundtrip_", fileext = ".h5")
+
+  mat <- matrix(complex(length.out = 30, real = 1:30, imaginary = 30:1), ncol = 10)
+  expect_silent(h5write(obj = mat, file = h5file, name = 'complex'))
+  
+  expect_silent(res <- h5read(file = h5file, name = 'complex'))
+  expect_is(res, 'matrix')
+  expect_type(res, 'complex')
+  expect_identical(res, mat)
+  expect_identical(h5read(file = h5file, name = 'complex', native = TRUE), t(mat))
+})
